@@ -90,11 +90,10 @@ class DrawingWindow(Gtk.ApplicationWindow):
 		self.app = kwargs['application']
 
 		self.header_bar = None
-		self.main_menu_btn = None
 
 		if self._settings.get_boolean('maximized'):
 			self.maximize()
-		# self.resize(360, 680) # XXX XXX XXX XXX XXX XXX XXX XXX XXX XXX XXX
+		# self.resize(360, 648) # XXX XXX XXX XXX XXX XXX XXX XXX XXX XXX XXX
 		self.set_ui_bars()
 
 	def init_window_content(self, gfile, get_cb):
@@ -122,40 +121,30 @@ class DrawingWindow(Gtk.ApplicationWindow):
 	def init_tools(self):
 		"""Initialize all tools, building the UI for them including the menubar,
 		and enable the default tool."""
-		disabled_tools_id = self._settings.get_strv('disabled-tools')
+		disabled_tools_ids = self._settings.get_strv('disabled-tools')
+		dev = self._settings.get_boolean('devel-only')
 		self.tools = {}
-		self.tools['pencil'] = ToolPencil(self)
-		self.tools['select'] = ToolSelect(self) # TODO
-		# self.tools['rectselect'] = ToolRectSelect(self)
-		# self.tools['freeselect'] = ToolFreeSelect(self)
-		# if 'colorselect' not in disabled_tools_id:
-		# 	self.tools['colorselect'] = ToolColorSelect(self)
-		self.tools['text'] = ToolText(self)
-		if 'picker' not in disabled_tools_id:
-			self.tools['picker'] = ToolPicker(self)
-		if 'paint' not in disabled_tools_id:
-			self.tools['paint'] = ToolPaint(self)
-		self.tools['line'] = ToolLine(self)
-		self.tools['arc'] = ToolArc(self)
-		self.tools['rectangle'] = ToolRectangle(self)
-		self.tools['circle'] = ToolCircle(self)
-		if 'polygon' not in disabled_tools_id:
-			self.tools['polygon'] = ToolPolygon(self)
-		self.tools['freeshape'] = ToolFreeshape(self)
-		if self._settings.get_boolean('devel-only'):
-			self.tools['experiment'] = ToolExperiment(self)
-		self.tools['crop'] = ToolCrop(self)
-		self.tools['scale'] = ToolScale(self)
-		self.tools['rotate'] = ToolRotate(self)
-		if 'flip' not in disabled_tools_id:
-			self.tools['flip'] = ToolFlip(self)
-		if 'saturate' not in disabled_tools_id:
-			self.tools['saturate'] = ToolSaturate(self)
+		self.load_tool('pencil', ToolPencil, disabled_tools_ids, dev)
+		self.load_tool('select', ToolSelect, disabled_tools_ids, dev)
+		self.load_tool('text', ToolText, disabled_tools_ids, dev)
+		self.load_tool('picker', ToolPicker, disabled_tools_ids, dev)
+		self.load_tool('paint', ToolPaint, disabled_tools_ids, dev)
+		self.load_tool('line', ToolLine, disabled_tools_ids, dev)
+		self.load_tool('arc', ToolArc, disabled_tools_ids, dev)
+		self.load_tool('rectangle', ToolRectangle, disabled_tools_ids, dev)
+		self.load_tool('circle', ToolCircle, disabled_tools_ids, dev)
+		self.load_tool('polygon', ToolPolygon, disabled_tools_ids, dev)
+		self.load_tool('freeshape', ToolFreeshape, disabled_tools_ids, dev)
+		if dev:
+			self.load_tool('experiment', ToolExperiment, disabled_tools_ids, dev)
+		self.load_tool('crop', ToolCrop, disabled_tools_ids, dev)
+		self.load_tool('scale', ToolScale, disabled_tools_ids, dev)
+		self.load_tool('rotate', ToolRotate, disabled_tools_ids, dev)
+		self.load_tool('flip', ToolFlip, disabled_tools_ids, dev)
+		self.load_tool('saturate', ToolSaturate, disabled_tools_ids, dev)
 
-		# Buttons for tools (in the side panel and the selection tool action bar)
+		# Side panel buttons for tools, and their menu-items if they don't exist
 		self.build_tool_rows()
-
-		# Global menubar
 		if not self.app.has_tools_in_menubar:
 			drawing_tools_section = self.app.get_menubar().get_item_link(4, \
 			      Gio.MENU_LINK_SUBMENU).get_item_link(0, Gio.MENU_LINK_SECTION)
@@ -180,6 +169,17 @@ class DrawingWindow(Gtk.ApplicationWindow):
 		else:
 			self.active_tool().row.set_active(True)
 
+	def load_tool(self, tool_id, tool_class, disabled_tools_ids, dev):
+		"""Given its id and its python class, this method tries to load a tool,
+		and show an error message if the tool initialization failed."""
+		if dev: # Simplest way to get an error stack
+			self.tools[tool_id] = tool_class(self)
+		elif tool_id not in disabled_tools_ids:
+			try:
+				self.tools[tool_id] = tool_class(self)
+			except:
+				self.prompt_message(True, _("Failed to load tool: %s") % tool_id)
+
 	############################################################################
 	# TABS AND WINDOWS MANAGEMENT ##############################################
 
@@ -279,6 +279,7 @@ class DrawingWindow(Gtk.ApplicationWindow):
 		self.options_btn.connect('toggled', self.update_option_label)
 		self._settings.connect('changed::show-labels', self.on_show_labels_setting_changed)
 		self._settings.connect('changed::decorations', self.on_layout_changed)
+		self._settings.connect('changed::big-icons', self.on_icon_size_changed)
 		self.notebook.connect('switch-page', self.on_active_tab_changed)
 
 	def add_action_simple(self, action_name, callback, shortcuts):
@@ -314,11 +315,6 @@ class DrawingWindow(Gtk.ApplicationWindow):
 		"""This doesn't add all window-wide GioActions, but only the GioActions
 		which are here "by default", independently of any tool."""
 
-		# TODO ??
-		# action = Gio.PropertyAction.new('main_menu', self.main_menu_btn, 'active')
-		# self.window.add_action(action)
-		# self.window.app.set_accels_for_action('win.main_menu', ['F10'])
-
 		self.add_action_simple('main_menu', self.action_main_menu, ['F10'])
 		self.add_action_simple('options_menu', self.action_options_menu, ['<Shift>F10'])
 		self.add_action_simple('properties', self.action_properties, None)
@@ -389,7 +385,7 @@ class DrawingWindow(Gtk.ApplicationWindow):
 		self.get_window().set_cursor(cursor)
 
 	############################################################################
-	# WINDOW BARS ##############################################################
+	# WINDOW DECORATIONS AND LAYOUTS ###########################################
 
 	def on_layout_changed(self, *args):
 		if self.header_bar is not None:
@@ -485,7 +481,6 @@ class DrawingWindow(Gtk.ApplicationWindow):
 			self.build_headerbar(True)
 			self.set_titlebar(self.header_bar.header_bar)
 			self.set_show_menubar(False)
-			# self.minimap_btn.set_border_width(6) # XXX faisable mais bof, et il faudrait l'annuler pour les autres
 		elif self.decorations == 'everything': # devel-only
 			self.build_headerbar(False)
 			self.set_titlebar(self.header_bar.header_bar)
@@ -540,8 +535,8 @@ class DrawingWindow(Gtk.ApplicationWindow):
 		self.header_bar = DrawingAdaptativeHeaderBar(is_eos)
 
 	def action_main_menu(self, *args):
-		if self.main_menu_btn is not None:
-			self.main_menu_btn.set_active(not self.main_menu_btn.get_active())
+		if self.header_bar is not None:
+			self.header_bar.toggle_menu()
 
 	def action_options_menu(self, *args):
 		"""This displays/hides the tool's options menu, and is implemented as an
@@ -585,8 +580,7 @@ class DrawingWindow(Gtk.ApplicationWindow):
 		should_shrink = self.limit_size_bottom > 0.7 * available_width
 		self.compact_bottombar(should_shrink)
 
-		# Update the scrollbars
-		self.get_active_image().add_deltas(0, 0, 0)
+		self.get_active_image().fake_scrollbar_update()
 
 	def compact_bottombar(self, state):
 		self.options_long_box.set_visible(not state)
@@ -612,6 +606,10 @@ class DrawingWindow(Gtk.ApplicationWindow):
 	############################################################################
 	# TOOLS PANEL ##############################################################
 
+	def on_icon_size_changed(self, *args):
+		for tool_id in self.tools:
+			self.tools[tool_id].update_icon_size()
+
 	def build_tool_rows(self):
 		"""Adds each tool's button to the side panel, or to the selection's
 		bottom panel."""
@@ -875,6 +873,7 @@ class DrawingWindow(Gtk.ApplicationWindow):
 	# SELECTION MANAGEMENT #####################################################
 
 	def action_getvalues(self, *args):
+		"""Development only"""
 		self.get_active_image().selection.print_values()
 
 	def action_select_all(self, *args):
@@ -991,17 +990,7 @@ class DrawingWindow(Gtk.ApplicationWindow):
 		"""Initialize the 2 color buttons and popovers with the 2 previously
 		memorized RGBA values."""
 		right_rgba = self._settings.get_strv('last-right-rgba')
-		r = float(right_rgba[0])
-		g = float(right_rgba[1])
-		b = float(right_rgba[2])
-		a = float(right_rgba[3])
-		right_rgba = Gdk.RGBA(red=r, green=g, blue=b, alpha=a)
 		left_rgba = self._settings.get_strv('last-left-rgba')
-		r = float(left_rgba[0])
-		g = float(left_rgba[1])
-		b = float(left_rgba[2])
-		a = float(left_rgba[3])
-		left_rgba = Gdk.RGBA(red=r, green=g, blue=b, alpha=a)
 		self.color_popover_r = DrawingColorPopover(self.color_menu_btn_r, \
 		                                           self.r_btn_image, right_rgba)
 		self.color_popover_l = DrawingColorPopover(self.color_menu_btn_l, \
